summaryrefslogtreecommitdiff
path: root/examples/gtalk_custom_domain.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/gtalk_custom_domain.py')
-rwxr-xr-xexamples/gtalk_custom_domain.py18
1 files changed, 9 insertions, 9 deletions
diff --git a/examples/gtalk_custom_domain.py b/examples/gtalk_custom_domain.py
index c974fc55..b12a047f 100755
--- a/examples/gtalk_custom_domain.py
+++ b/examples/gtalk_custom_domain.py
@@ -2,9 +2,9 @@
# -*- coding: utf-8 -*-
"""
- SleekXMPP: The Sleek XMPP Library
+ Slixmpp: The Slick XMPP Library
Copyright (C) 2010 Nathanael C. Fritz
- This file is part of SleekXMPP.
+ This file is part of Slixmpp.
See the file LICENSE for copying permission.
"""
@@ -14,33 +14,33 @@ import logging
import getpass
from optparse import OptionParser
-import sleekxmpp
+import slixmpp
import ssl
-from sleekxmpp.xmlstream import cert
+from slixmpp.xmlstream import cert
# Python versions before 3.0 do not use UTF-8 encoding
# by default. To ensure that Unicode is handled properly
# throughout SleekXMPP, we will set the default encoding
# ourselves to UTF-8.
if sys.version_info < (3, 0):
- from sleekxmpp.util.misc_ops import setdefaultencoding
+ from slixmpp.util.misc_ops import setdefaultencoding
setdefaultencoding('utf8')
else:
raw_input = input
-class GTalkBot(sleekxmpp.ClientXMPP):
+class GTalkBot(slixmpp.ClientXMPP):
"""
- A demonstration of using SleekXMPP with accounts from a Google Apps
+ A demonstration of using Slixmpp with accounts from a Google Apps
account with a custom domain, because it requires custom certificate
validation.
"""
def __init__(self, jid, password):
- sleekxmpp.ClientXMPP.__init__(self, jid, password)
+ slixmpp.ClientXMPP.__init__(self, jid, password)
# The session_start event will be triggered when
# the bot establishes its connection with the server
@@ -14,33 +14,33 @@ import logging
# Python versions before 3.0 do not use UTF-8 encoding
# by default. To ensure that Unicode is handled properly
-# throughout SleekXMPP, we will set the default encoding
+# throughout Slixmpp, we will set the default encoding
# ourselves to UTF-8.
if sys.version_info < (3, 0):